<?php
require_once("class/class.conectar.php");
require_once("class/class.usudep.php");
require_once("class/class.usutrab.php");
require_once("class/class.usuaprueba.php");
require_once("class/class.garea.php");
require_once("class/class.area.php");
require_once("class/class.horario.php");
require_once("class/class.personal.php");
require_once("class/class.jefaturas.php");
require_once("class/class.tipopersonal.php");
require_once("class/class.subprogxarea.php");
require_once("class/class.consolhorareprog.php");
require_once("class/class.horareprog.php");
require_once("class/class.diaferiado.php");
require_once("class/class.subreprogxarea.php");
require_once("class/class.descmed.php");
require_once("class/class.licencia.php");

$Objcon = new Conectar();
$conex = $Objcon->con();

//se recibe los parametros
$idj=$_GET['idj'];
$ids=$_GET['ids'];
$anno=$_GET['anno'];
$mm=$_GET['mes'];
$idtp=$_GET['idtp'];
$idga=$_GET['idga'];
$ugid=$_GET['ugid'];

date_default_timezone_set("America/Lima"); setlocale(LC_TIME,"es_PE.UTF-8");

$arraymes = array();
$arraymes[] = array('idmes'=>'1','mes'=>'ENERO');
$arraymes[] = array('idmes'=>'2','mes'=>'FEBRERO');
$arraymes[] = array('idmes'=>'3','mes'=>'MARZO');
$arraymes[] = array('idmes'=>'4','mes'=>'ABRIL');
$arraymes[] = array('idmes'=>'5','mes'=>'MAYO');
$arraymes[] = array('idmes'=>'6','mes'=>'JUNIO');
$arraymes[] = array('idmes'=>'7','mes'=>'JULIO');
$arraymes[] = array('idmes'=>'8','mes'=>'AGOSTO');
$arraymes[] = array('idmes'=>'9','mes'=>'SETIEMBRE');
$arraymes[] = array('idmes'=>'10','mes'=>'OCTUBRE');
$arraymes[] = array('idmes'=>'11','mes'=>'NOVIEMBRE');
$arraymes[] = array('idmes'=>'12','mes'=>'DICIEMBRE');

//armar el encabezado de las fechas
$mes = mktime( 0, 0, 0, $mm, 1, $anno );
$numeroDeDias = intval(date("t",$mes));

$cabcal="<table>";
$cabcal=$cabcal."<tr><td rowspan='2' class='facetfilaTD' width='100'>AREA</td><td rowspan='2' class='facetfilaTD'>HORARIO</td><td rowspan='2' class='facetfilaTD'>TURNO</td><td rowspan='2' class='facetfilaTD'>NH</td>";
for ($i=1;$i<=$numeroDeDias;$i++){
$dia= date("w",mktime( 0, 0, 0, $mm, $i, $anno ));
$fechacal = $anno.'-'.$mes.'-'.$dia;
//dia feriado
$diaft=0;
$Objdf = new DiaFeriado();
$res_df=array();
$res_df=$Objdf->buscar_dia_feriado($conex,$fechacal);

if(count($res_df)>0){
$diaft=$res_df[0]['tipo'];
}

switch ($dia) {
    case 0:
        $cabcal=$cabcal."<td width='20' align='center' class='facetdataTDR'><b>DOM</b></td>";
        break;
    case 1:
        $cabcal=$cabcal."<td width='20' align='center'";if($diaft==1){ $cabcal=$cabcal." class='facetdataTDR'><b>LUN</b></td>";}elseif($diaft==2){$cabcal=$cabcal." class='facetdataTDNL'><b>LUN</b></td>";}else{ $cabcal=$cabcal." class='facetdataTD'>LUN</td>"; }
		break;
    case 2:
        $cabcal=$cabcal."<td width='20' align='center'";if($diaft==1){ $cabcal=$cabcal." class='facetdataTDR'><b>MAR</b></td>";}elseif($diaft==2){$cabcal=$cabcal." class='facetdataTDNL'><b>MAR</b></td>";}else{ $cabcal=$cabcal." class='facetdataTD'>MAR</td>"; }
        break;
	case 3:
        $cabcal=$cabcal."<td width='20' align='center'";if($diaft==1){ $cabcal=$cabcal." class='facetdataTDR'><b>MIE</b></td>";}elseif($diaft==2){$cabcal=$cabcal." class='facetdataTDNL'><b>MIE</b></td>";}else{ $cabcal=$cabcal." class='facetdataTD'>MIE</td>"; }
        break;
	case 4:
        $cabcal=$cabcal."<td width='20' align='center'";if($diaft==1){ $cabcal=$cabcal." class='facetdataTDR'><b>JUE</b></td>";}elseif($diaft==2){$cabcal=$cabcal." class='facetdataTDNL'><b>JUE</b></td>";}else{ $cabcal=$cabcal." class='facetdataTD'>JUE</td>"; }
        break;
	case 5:
        $cabcal=$cabcal."<td width='20' align='center'";if($diaft==1){ $cabcal=$cabcal." class='facetdataTDR'><b>VIE</b></td>";}elseif($diaft==2){$cabcal=$cabcal." class='facetdataTDNL'><b>VIE</b></td>";}else{ $cabcal=$cabcal." class='facetdataTD'>VIE</td>"; }
        break;
	case 6:
        $cabcal=$cabcal."<td width='20' align='center'";if($diaft==1){ $cabcal=$cabcal." class='facetdataTDR'><b>SAB</b></td>";}elseif($diaft==2){$cabcal=$cabcal." class='facetdataTDNL'><b>SAB</b></td>";}else{ $cabcal=$cabcal." class='facetdataTD'>SAB</td>"; }
        break;
}}
$cabcal=$cabcal."<td rowspan='2' class='facetfilaTD'><b>EDIT</b></td></tr><tr>";

//los numeros de la cabecera
for ($i=1;$i<=$numeroDeDias;$i++){
$dia= date("w",mktime( 0, 0, 0, $mm, $i, $anno ));
$fechacal = $anno.'-'.$mes.'-'.$dia;
//dia feriado
$diaft=0;
$Objdf = new DiaFeriado();
$res_df=array();
$res_df=$Objdf->buscar_dia_feriado($conex,$fechacal);

if(count($res_df)>0){
$diaft=$res_df[0]['tipo'];
}

switch ($dia) {
    case 0:
        $cabcal=$cabcal."<td align='center' class='facetfilaTD'><b>$i</b></td>";
        break;
    case 1:
    case 2:
    case 3:
    case 4:
    case 5:
    case 6:
        $cabcal=$cabcal."<td align='center' ";if($diaft==1){ $cabcal=$cabcal." class='facetfilaTD'><b>$i</b></td>";}elseif($diaft==2){$cabcal=$cabcal." class='facetfilaTD'><b>$i</b></td>";}else{ $cabcal=$cabcal." class='facetfilaTD'>$i</td>"; }
        break;
}}
$cabcal=$cabcal."</tr>";

//nombre de la jefaturas
$Objj = new Jefaturas();
$res_jef = array();$res_serv = array();
$res_jef=$Objj->buscar_jefatura($conex,$idj);
$nomjefatura=$res_jef[0]['nom'];
if($ids!=0){
$res_serv=$Objj->buscar_jefatura_servicio($conex,$idj,$ids);
$nomservicio=$res_serv[0]['nom'];
}else{
$nomservicio="";
}

//nombre de tipo de personal
$Objtp = new TipoPersonal();
$res_tp=array();
$res_tp=$Objtp->buscar_tipoper($conex,$idtp);
$tipoper=$res_tp[0]['nom'];

?>
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1" />
<title>SISTEMA INTEGRADO DE LA PROGRAMACION ASISTENCIAL</title>
<link rel="stylesheet" type="text/css" href="styles/Style.css">
<script language="JavaScript" type="text/javascript" src="ajax.js"></script>
<script type="text/javascript">
//ver programacion
function verprog(num){
//alert(ugid);
var ugid = document.getElementById("cod"+num).value;
var mes = document.getElementById("mes").value;
var anno= document.getElementById("anno").value;
var idj= document.getElementById("depa").value;
var ids= document.getElementById("serv").value;
window.open("verdetallerepro.php?ugid="+ugid+"&anno="+anno+"&mes="+mes+"&idjp="+idj+"&idsp="+ids,"","height=500,width=1250,scrollbars=YES");
}

function verdetallesusp(num){
var ugid = document.getElementById("coda"+num).value;
var mes = document.getElementById("mes").value;
var anno= document.getElementById("anno").value;
var idj= document.getElementById("depa").value;
var ids= document.getElementById("serv").value;
window.open("verdetallehrsusp.php?ugid="+ugid+"&anno="+anno+"&mes="+mes+"&idjp="+idj+"&idsp="+ids,"","height=500,width=1250,scrollbars=YES");
}

function agregapersonalrepro(){
//alert(ugid);
var mes = document.getElementById("mes").value;
var anno= document.getElementById("anno").value;
var idj= document.getElementById("depa").value;
var ids= document.getElementById("serv").value;
var idtp= document.getElementById("idtp").value;
window.open("buscarpersonalrepro.php?anno="+anno+"&mes="+mes+"&idj="+idj+"&ids="+ids+"&idtp="+idtp,"","height=280,width=700,scrollbars=NO");
}
</script>
</head>
<body>
<br>
<hr color='blue' size='10'>
<table align='center'><tr><td>
<table align='center'>
<tr><td align='center'><font color='red'><b><?php echo $nomjefatura;?></b></font></td></tr>
<tr><td align='center'><font color='blue'><b><?php echo $nomservicio;?></b></font></td></tr>

<tr><td align='center'><font color='blue' size='5'><b>REPROGRAMACION DEL MES DE <?php echo $arraymes[$mm-1]['mes'];?> DEL <?php echo $anno; ?></b></font></td></tr>
<tr><td align='center'><font color='blue'><b><?php echo $tipoper;?></b></font></td></tr>
</table></td><td>
<img src='img/home.png' width='70' height='60' onClick='regresarMP()'>
</td></tr></table>
<hr color='blue' size='10'>
<table align='center'>
<tr><td colspan='8' align='center' class='TDTituloP'>INDICADORES DE OBSERVACIONES</td></tr>
<tr><td width='70' class='indicador' align='center'>CRUCE HORARIO</td><td width='70' class='indicador' align='center'>POST GUARDIA</td><td width='70' class='indicador' align='center'>ONOMASTICO</td><td width='70' class='indicador' align='center'>VACACIONES</td><td width='70' class='indicador' align='center'>DESCANSO MEDICO<td width='70' class='indicador' align='center'>CRUCE HORARIO OS</td><td width='70' class='indicador' align='center'>POST GUARDIA OS</td><td width='70' class='indicador' align='center'>MAS 10 GUARDIAS</td></tr>
<tr><td bgcolor='red' height='15' ></td><td bgcolor='green' height='15'></td><td bgcolor='#48A3F3' ></td><td bgcolor='litlegreen'></td><td bgcolor='brown'></td><td bgcolor='pink'></td><td bgcolor='purple'></td ><td bgcolor='orange'></td></tr>
<tr><td width='70' class='indicador' align='center'></td><td width='70' class='indicador' align='center'>HRS PERMISO</td><td width='70' class='indicador' align='center'>LICENCIA</td><td width='70' class='indicador' align='center'>MAS DE 3 DIAS</td><td width='70' class='indicador' align='center'>SUPERPOSICION</td><td width='70' class='indicador' align='center'>DESC. POR RADIACION</td><td width='70' class='indicador' align='center'></td><td width='70' class='indicador' align='center'></td></tr>
<tr><td  height='15' ></td><td height='15' align='center' bgcolor='white'><img src='' border=0 height='5' width='5' style='background-color:#FF0000;'></td><td bgcolor='#CC66FF'></td><td bgcolor='#FF00CC'></td><td bgcolor='#CCCC00'></td><td bgcolor='#99FF66'></td><td ></td ><td ></td></tr>
</table>
<br>
<table align="center">
<tr><td align="center"><input type="button" value="Regresar" onClick="regresarmenurepro()"></td></tr>
<?php
echo "<input type='hidden' id='depa' value='".$idj."'>";
echo "<input type='hidden' id='serv' value='".$ids."'>";
echo "<input type='hidden' id='idtp' value='".$idtp."'>";
echo "<input type='hidden' id='mes' value='".$mm."'>";
echo "<input type='hidden' id='anno' value='".$anno."'>";
echo "<input type='hidden' id='ugid' value='".$ugid."'>";
echo "<input type='hidden' id='ugid' value='".$idga."'>";

//agrupar los grupos areas del servicio
$Objga = new GrupoArea();
$res_ga=array();
$res_ga=$Objga->listar_garea_dep($conex,$idj,$ids,$idtp);
?>
<tr><td><?php if(isset($_GET['error'])){ echo $_GET['error'];}?></td></tr></table>
<?php

//para sacar la cantidad de divs
echo "<br><br><div id='divga".$idga."'>";

//pregunta por si existe turno en reprogramacion
$Objhrsp = new SubhoraReprogramado();
$res_progm=array();
$res_progm=$Objhrsp->ask_reprog_mes($conex,$anno,$mm,$idtp,$idj,$ids,$idga);

//if(count($res_progm)>0){
$idj= $idj;
$ids= $ids;
$idso= $ids;
$idga=$idga;
$anno= $anno;
$mm=$mm;
$conex=$conex;
include("rareasub.php");
//}
//termina de preguntar por programacion
echo "</div>";


echo "<br><center><div id='listadopersonal'";


//armando grupo de servicios y sus dependencias
$Objj = new Jefaturas();
$datosj[] = array();
$datosj1=$Objj->buscar_jefatura($conex,$idj);
$datosj2=$Objj->listar_jefatura_servicio($conex,$idj);
$datosj=array_merge($datosj1, $datosj2);
$cad="";

for($ij=0;$ij<sizeof($datosj);$ij++)
{
$cad = $cad."<td width='80' class='facetfilaTD' colspan='4' align='center' >".$datosj[$ij]['abrev']."</td>";
}

$cdhrs ="<td class='facetfilaTD' width='20' align='center'>GD</td><td class='facetfilaTD' width='20' align='center'>GN</td><td class='facetfilaTD' width='20' align='center'>HO</td><td class='facetfilaTD' width='20' align='center'>HE</td>";

$ncadena = 4*(count($datosj));
$ntotal = $ncadena + 13;
//echo "<b>cant ".$ntotal."</b><br>";
$cadena1 = "<br><table><tr><td colspan='$ntotal' align='center' class='LlenarTablaGarea'>LISTADO DEL PERSONAL PROGRAMADO</td></tr>";
$cadena1 = $cadena1."<tr><td colspan='$ntotal' align='center' class='facetfilaTD'><input type='button' id='newper' name='newper' value='Agregar Personal' onClick='agregapersonalrepro()'></td></tr>";
$cadena1 = $cadena1."<tr><td width='50' class='facetfilaTD' rowspan='3'>CODIGO</td><td width='260' class='facetfilaTD' rowspan='3' align='center'>NOMBRE DEL PERSONAL</td><td class='facetfilaTD' colspan='$ncadena' align='center'>SERVICIOS PROGRAMADOS</td><td class='facetfilaTD' align='center' rowspan='2' colspan='2'  >HRS ORD SUSPENDIDAS</td><td class='facetfilaTD' align='center' rowspan='2' colspan='4'  >TOTALES</td><td class='facetfilaTD' align='center' rowspan='3'>HRS A <br>PROGRAMAR<br> X MES</td><td class='facetfilaTD' align='center' rowspan='3'>PROG<BR>INDIVIDUAL</td><td class='facetfilaTD' align='center' rowspan='3' width='250'> OBSERVACIONES </td></tr>";
$cadena1 = $cadena1."<tr>".$cad."</tr>";

//etiquetas de los hrs por los servicios
$cadena1 = $cadena1."<tr>";
for($i=0;$i<count($datosj);$i++){
$cadena1 = $cadena1.$cdhrs;
}

$cadena1 = $cadena1."<td class='facetfilaTD' width='40' align='center'>HRS</td><td align='center' class='facetfilaTD' width='40'>DET</td>".$cdhrs."</tr>";

//horas por los servicios//pregunta por el personal
$Objp = new UsuarioTrabaja();
$s=0;
$res_per=array();
$res_per=$Objp->listar_per_trab_per_serv($conex,$anno,$mm,$idj,$ids,$idtp);
$registro="";
for($ip=0;$ip<count($res_per);$ip++)
{
$ugid = $res_per[$ip]['cod'];
$codprog = $res_per[$ip]['codigo'];
$nombre = $res_per[$ip]['nombre'];
$observacion = $res_per[$ip]['obs2'];

$registro=$registro."<tr><td align='center' class='FacetDataTextC'>".$codprog."</td><td class='FacetDataTextC'>".$nombre."</td>";

//listado al persoonal
for($i=0;$i<count($datosj);$i++){
$idso =  $datosj[$i]['ids'];

$Objchp = new ConsolHoraReprogramacion();
$res_chps = array();
$res_chps =$Objchp->consol_hrreprog_serv($conex,$ugid,$anno,$mm,$idj,$idso,$idtp);

		if(count($res_chps)==0){
			$registro=$registro."<td class='FacetDataTextC' align='center'>-</td><td class='FacetDataTextC' align='center'>-</td><td class='FacetDataTextC' align='center'>-</td><td class='FacetDataTextC' align='center'>-</td>";
	}else{
		for ($ichs=0;$ichs<count($res_chps);$ichs++){
		$registro=$registro."<td class='FacetDataTextC' align='center'>".$res_chps[$ichs]['gd']."</td><td class='FacetDataTextC' align='center'>".$res_chps[$ichs]['gn']."</td><td class='FacetDataTextC' align='center'>".$res_chps[$ichs]['ho']."</td><td class='FacetDataTextC' align='center'>".$res_chps[$ichs]['he']."</td>";
	}
	}
}
//echo $ugid."<br>";
$numhrsDMs=0; $numhrslic = 0; $numhrsdr = 0;

//total de horas suspendidas x descanso medico
$Objdm = new DescansoMedico();
$numhrsDMs = $Objdm->consultar_descmed_hrssuspen($conex,$ugid,$idtp,$anno,$mm,0);
	if($numhrsDMs==0){
		$numhrsdm=0;
	}else{
		$numhrsdm = $numhrsDMs;
	}

//total de horas suspendidas x licenciatura
$Objlic = new Licencia();
$numhrsl = $Objlic->consultar_licencia_hrssusp($conex,$ugid,$idtp,$anno,$mm,0);

	if($numhrsl==0){
		$numhrslic = 0;
	}else{
		$numhrslic = $numhrsl;
	}
$s=$s+1;
$tothrssus=0;
if(($numhrsdm + $numhrslic)>0){
$tothrssus=$numhrsdm + $numhrslic;
//$codigoa2 = $codigoa2."<input type='hidden' id='coda".$aa."' value='".$ugid."'>";
$registro=$registro."<td align='center' class='FacetDataTextC'>".$tothrssus."</td><td align='center' class='FacetDataTextC'><input type='hidden' id='coda".$s."' value='".$ugid."'><img src='img/ver.jpg' width='17' height='17' value='$ugid' onClick=verdetallesusp(".$s.");></td>";
}else{
//$codigoa2 = $codigoa2."<input type='hidden' id='coda".$aa."' value='".$ugid."'>";
$registro=$registro."<td class='FacetDataTextC' align='center'>0</td><td class='FacetDataTextC' align='center'><input type='hidden' id='coda".$s."' value='".$ugid."'><img src='img/ver.jpg' width='17' height='17' value='$ugid' onClick=verdetallesusp(".$s.");></td>";
}
	//total de horas
	$res_chp = array();
	$res_chp =$Objchp->consol_hrreprog($conex,$ugid,$anno,$mm,$idtp);

	if(count($res_chp)==0){
			$registro=$registro."<td align='center' class='FacetDataTextC'>0</td><td align='center' class='FacetDataTextC'>0</td><td align='center' class='FacetDataTextC'>0</td><td align='center' class='FacetDataTextC'>0</td>";
			echo 0;
	}else{
		for ($ich=0;$ich<count($res_chp);$ich++){
		$registro=$registro."<td align='center' class='FacetDataTextC'>".$res_chp[$ich]['tgd']."</td><td align='center' class='FacetDataTextC'>".$res_chp[$ich]['tgn']."</td><td align='center' class='FacetDataTextC'>".$res_chp[$ich]['tho']."</td><td align='center' class='FacetDataTextC'>".$res_chp[$ich]['the']."</td>";
	}}


//cantidad de horas programadas por mes
$Objp = new Personal();
$thrs = $Objp->contar_hrsprog($conex,$ugid);
		$registro=$registro."<td align='center' class='FacetDataTextC'>".$thrs."</td><td align='center' class='FacetDataTextC'><input type='hidden' id='cod".$s."' value='".$ugid."'><img src='img/ver.jpg' width='17' height='17' onClick=verprog($s);></td><td align='center' class='FacetDataTextC'>".$observacion."</td></tr>";


}
ECHO $cadena1.$registro."</table>"; //$codigoa1.$codigoa2.
///////////
echo "</div><br></center>";

?>
</body>
</html>
